﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using MotorBoat.DrawningObjects;
using MotorBoat.Generics;
using MotorBoat.MovementStrategy;

namespace MotorBoat
{
    /// <summary>
    /// Форма для работы с набором объектов класса DrawningBoat
    /// </summary>
    public partial class FormBoatCollection : Form
    {
        /// <summary>
        /// Набор объектов
        /// </summary>
        private readonly BoatsGenericCollection<DrawningBoat, DrawningObjectBoat> _boats;

        /// <summary>
        /// Конструктор
        /// </summary>
        public FormBoatCollection()
        {
            InitializeComponent();
            _boats = new BoatsGenericCollection<DrawningBoat, DrawningObjectBoat>(pictureBoxCollection.Width, pictureBoxCollection.Height);
        }

        /// <summary>
        /// Добавление объекта в набор
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonAddBoat_Click(object sender, EventArgs e)
        {
            FormMotorBoat form = new();
            if (form.ShowDialog() == DialogResult.OK)
            {
                if (_boats + form.SelectedBoat != -1)
                {
                    MessageBox.Show("Объект добавлен");
                    pictureBoxCollection.Image = _boats.ShowBoats();
                }
                else
                {
                    MessageBox.Show("Не удалось добавить объект");
                }
            }
        }

        /// <summary>
        /// Удаление объекта из набора
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonRemoveBoat_Click(object sender, EventArgs e)
        {
            if (MessageBox.Show("Удалить объект?", "Удаление",
                MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
            {
                return;
            }
            int pos = Convert.ToInt32(maskedTextBoxNumber.Text);
            if (_boats - pos != null)
            {
                MessageBox.Show("Объект удален");
                pictureBoxCollection.Image = _boats.ShowBoats();
            }
            else
            {
                MessageBox.Show("Не удалось удалить объект");
            }

        }

        /// <summary>
        /// Обновление рисунка по набору
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonRefreshCollection_Click(object sender, EventArgs e)
        {
            pictureBoxCollection.Image = _boats.ShowBoats();
        }
    }
}